.. pebaystats documentation master file, created by
   sphinx-quickstart on Sat Nov 12 16:24:06 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pebaystats - single pass descriptive statistical moments
========================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   authors
   history

.. automodule:: pebaystats

.. autoclass:: dstats
    :members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

